@@ -1128,6 +1128,10 @@ class TestBluetoothAssignedNumbers(TestCase):
             IOBluetooth.kBluetoothHCIExtendedInquiryResponseDataTypeTransportDiscoveryData,
             0x26,
         )
+        self.assertEqual(
+            IOBluetooth.kBluetoothHCIExtendedInquiryResponseDataTypeCsisRsiData,
+            0x2E,
+        )
         self.assertEqual(
             IOBluetooth.kBluetoothHCIExtendedInquiryResponseDataType3DInformationData,
             0x3D,
